# Python re(gex)? playground

This TUI application is intended as an interactive playground for Python Regular Expressions. The app also includes a comprehensive cheatsheet and several interactive examples.

# Screenshot

![Sample screenshot from the Playground screen](https://github.com/learnbyexample/TUI-apps/raw/main/PyRegexPlayground/pyregex_finditer.png)

![Sample screenshot from the Interactive Examples screen](https://github.com/learnbyexample/TUI-apps/raw/main/PyRegexPlayground/pyregex_examples.png)

# Guide

See [app_guide.md](https://github.com/learnbyexample/TUI-apps/blob/main/PyRegexPlayground/app_guide.md)

# License

Code snippets are licensed under [MIT LICENSE](https://github.com/learnbyexample/TUI-apps/blob/main/LICENSE)

Explanations and associated files (like `cheatsheet.md`) are licensed under [Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License](https://creativecommons.org/licenses/by-nc-sa/4.0/)

